Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
ErrBlobNotFound indicates that the requested blob did not exit
Functions ¶
This section is empty.
Types ¶
type Blob ¶
type Blob struct {
ID string `json:"blob_id,omitempty"`
ContentType string `json:"content_type,omitempty"`
Length int64 `json:"length,omitempty"`
}
Blob encapsulates details of a blob in a remote store
type Server ¶
Server encapsulates the blob server
type Store ¶
type Store interface {
// Read Read a blob from a BlobDatum from the store
Read(prefix string, blobID string) (io.Reader, error)
// Create creates a new blob object associated with a given graph
Create(prefix string, contentType string, content io.Reader) (*Blob, error)
}
Store is an abstraction for user data persistence user data is a pure blob with no semantics
Source Files
¶
- blobapi.go
- blobs.go
- inmem_blob_store.go
- sql_blob_store.go
Click to show internal directories.
Click to hide internal directories.