Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFnSpan ¶
func NewFnSpan(s opentracing.Span) opentracing.Span
NewFnSpan returns a new FnSpan which wraps the specified Span
func NewFnTracer ¶
func NewFnTracer(t opentracing.Tracer) opentracing.Tracer
NewFnTracer returns a new FnTracer which wraps the specified Tracer
Types ¶
type FnSpan ¶
type FnSpan struct {
opentracing.Span
}
FnSpan is a custom Span that wraps another span which adds some extra behaviour required for sending tracing spans to prometheus
func (FnSpan) FinishWithOptions ¶
func (fns FnSpan) FinishWithOptions(opts opentracing.FinishOptions)
FinishWithOptions implements opentracing.Span
type FnTracer ¶
type FnTracer struct {
opentracing.Tracer
}
FnTracer is a custom Tracer which wraps another another tracer its main purpose is to wrap the underlying Span in a FnSpan, which adds some extra behaviour required for sending tracing spans to prometheus
func (FnTracer) StartSpan ¶
func (fnt FnTracer) StartSpan(operationName string, opts ...opentracing.StartSpanOption) opentracing.Span
StartSpan implements opentracing.Tracer Override StartSpan to wrap the returned Span in a FnSpan
type InternalServer ¶
type InternalServer struct {
// contains filtered or unexported fields
}
InternalServer handles the node-local service (servicing graphs on this node only)
func NewInternalFlowService ¶
func NewInternalFlowService(flows model.FlowServiceServer, listen string) (*InternalServer, error)
NewInternalFlowService creates a new flow service for a given graph API
func (*InternalServer) Run ¶
func (s *InternalServer) Run() error
Run starts the server and blocks until it closes
type PrometheusCollector ¶
type PrometheusCollector struct {
// contains filtered or unexported fields
}
PrometheusCollector is a custom Collector which sends ZipKin traces to Prometheus
func (PrometheusCollector) Close ¶
func (PrometheusCollector) Close() error
Close implements Collector.
func (PrometheusCollector) Collect ¶
func (pc PrometheusCollector) Collect(span *zipkincore.Span) error
Collect implements Collector.
Source Files
¶
- fntracer.go
- internal_server.go
- metrics.go
- prom_zip_collector.go
- server.go