Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterProxy ¶
func NewClusterProxy(manager *Manager) model.FlowServiceServer
NewClusterProxy creates a proxy service that forwards requests to the appropriate nodes based on the request shard
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager manages cluster allocation and shard info
func NewManager ¶
func NewManager(settings *Settings, extractor sharding.ShardExtractor) *Manager
NewManager creates a new cluster manager
func (*Manager) GetClient ¶
func (m *Manager) GetClient(flowID string) (model.FlowServiceClient, error)
GetClient returns a GRPC client for the specified graph
func (*Manager) GetClients ¶
func (m *Manager) GetClients() (clients []model.FlowServiceClient, err error)
GetClients returns GRPC clients for all the nodes
Source Files
¶
- cluster.go
- cluster_proxy.go
Click to show internal directories.
Click to hide internal directories.